==> 1.0.5.tar.gz: sorcerycraft/src/main/java/com/thebrokenrail/sorcerycraft/entity/SpellEntity.java <==
package com.thebrokenrail.sorcerycraft.entity;

import com.thebrokenrail.sorcerycraft.SorceryCraft;
import com.thebrokenrail.sorcerycraft.spell.Spell;
import com.thebrokenrail.sorcerycraft.spell.SpellRegistry;
import com.thebrokenrail.sorcerycraft.spell.SpellTag;
import com.thebrokenrail.sorcerycraft.spell.Spells;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.entity.Entity;
import net.minecraft.entity.EntityType;
import net.minecraft.entity.LivingEntity;
import net.minecraft.entity.player.PlayerEntity;
import net.minecraft.entity.thrown.ThrownItemEntity;
import net.minecraft.item.Item;
import net.minecraft.network.Packet;
import net.minecraft.network.packet.s2c.play.EntitySpawnS2CPacket;
import net.minecraft.particle.ParticleTypes;
import net.minecraft.sound.SoundCategory;
import net.minecraft.sound.SoundEvents;
import net.minecraft.util.Identifier;
import net.minecraft.util.hit.EntityHitResult;
import net.minecraft.util.hit.HitResult;
import net.minecraft.world.World;

import java.util.Map;

public class SpellEntity extends ThrownItemEntity {
    public SpellEntity(EntityType<SpellEntity> entityType, World world) {
        super(entityType, world);
    }

    public SpellEntity(World world, LivingEntity owner) {
        super(SorceryCraft.SPELL_ENTITY, owner, world);
    }

    private boolean firstTick = true;

    public SpellEntity(World world, double x, double y, double z) {
        super(SorceryCraft.SPELL_ENTITY, x, y, z, world);
    }

    private boolean didSpellSucceed(Map<Identifier, Integer> spells) {
        return Math.random() > SorceryCraft.SPELL_FAILURE_CHANCE || spells.containsKey(Spells.STEADFAST_SPELL);
    }

    @Override
    protected void onCollision(HitResult hitResult) {
        Map<Identifier, Integer> spells = SpellTag.getSpells(getItem());
        if (!spells.containsKey(Spells.INWARD_SPELL)) {
            if (hitResult.getType() == HitResult.Type.BLOCK) {
                remove();
            } else if (hitResult.getType() == HitResult.Type.ENTITY) {
                Entity entity = ((EntityHitResult) hitResult).getEntity();

                boolean success = didSpellSucceed(spells);
                for (Map.Entry<Identifier, Integer> entry : spells.entrySet()) {
                    Spell spell = SpellRegistry.getSpell(entry.getKey(), entry.getValue());
                    if (spell != null) {
                        if (success) {
                            spell.execute(entity, this, getOwner());
                        } else if (getOwner() != null) {
                            if (getOwner() instanceof PlayerEntity) {
                                PlayerEntity player = (PlayerEntity) getOwner();
                                player.playSound(SoundEvents.ENCHANT_THORNS_HIT, SoundCategory.PLAYERS, 1.0f, 1.0f);
                            }
                            spell.execute(getOwner(), this, getOwner());
                        }
                    }
                }

                remove();
            }
        }
    }

    @Override
    @Environment(EnvType.CLIENT)
    public void handleStatus(byte status) {
        if (status == 0) {
            for (int i = 0; i < 12; i++) {
                getEntityWorld().addParticle(ParticleTypes.WITCH, getX(), getY(), getZ(), 0.0d, 0.0d, 0.0d);
            }
        }
    }

    @Override
    public void tick() {
        super.tick();
        if (firstTick) {
            firstTick = false;
            Map<Identifier, Integer> spells = SpellTag.getSpells(getItem());
            if (spells.containsKey(Spells.INWARD_SPELL)) {
                if (getOwner() != null) {
                    boolean success = didSpellSucceed(spells);
                    for (Map.Entry<Identifier, Integer> entry : spells.entrySet()) {
                        Spell spell = SpellRegistry.getSpell(entry.getKey(), entry.getValue());
                        if (spell != null && success) {
                            spell.execute(getOwner(), this, getOwner());
                        }
                    }
                }
                remove();
                return;
            }
        }
        if (!getEntityWorld().isClient()) {
            getEntityWorld().sendEntityStatus(this, (byte) 0);
        }
    }

    @Override
    protected Item getDefaultItem() {
        return SorceryCraft.SPELL_ITEM;
    }

    @Override
    public Packet<?> createSpawnPacket() {
        return new EntitySpawnS2CPacket(this);
    }
}

==> 1.1.3.tar.gz: sorcerycraft/src/main/java/com/thebrokenrail/sorcerycraft/entity/SpellEntity.java <==
package com.thebrokenrail.sorcerycraft.entity;

import com.thebrokenrail.sorcerycraft.SorceryCraft;
import com.thebrokenrail.sorcerycraft.spell.api.Spell;
import com.thebrokenrail.sorcerycraft.spell.registry.SpellRegistry;
import com.thebrokenrail.sorcerycraft.spell.util.SpellTag;
import com.thebrokenrail.sorcerycraft.spell.registry.Spells;
import net.minecraft.entity.Entity;
import net.minecraft.entity.EntityType;
import net.minecraft.entity.LivingEntity;
import net.minecraft.entity.player.PlayerEntity;
import net.minecraft.entity.thrown.ThrownItemEntity;
import net.minecraft.item.Item;
import net.minecraft.network.Packet;
import net.minecraft.network.packet.s2c.play.EntitySpawnS2CPacket;
import net.minecraft.particle.ParticleTypes;
import net.minecraft.server.network.ServerPlayerEntity;
import net.minecraft.server.world.ServerWorld;
import net.minecraft.sound.SoundCategory;
import net.minecraft.sound.SoundEvents;
import net.minecraft.util.Identifier;
import net.minecraft.util.hit.BlockHitResult;
import net.minecraft.util.hit.EntityHitResult;
import net.minecraft.util.hit.HitResult;
import net.minecraft.world.World;

import java.util.List;
import java.util.Map;
import java.util.Objects;

public class SpellEntity extends ThrownItemEntity {
    public SpellEntity(EntityType<SpellEntity> entityType, World world) {
        super(entityType, world);
    }

    public SpellEntity(World world, LivingEntity owner) {
        super(SorceryCraft.SPELL_ENTITY, owner, world);
    }

    public SpellEntity(World world, double x, double y, double z) {
        super(SorceryCraft.SPELL_ENTITY, x, y, z, world);
    }

    private boolean didSpellSucceed(Map<Identifier, Integer> spells) {
        return Math.random() > SorceryCraft.SPELL_FAILURE_CHANCE || spells.containsKey(Spells.STEADFAST_SPELL);
    }

    @Override
    protected void onCollision(HitResult hitResult) {
        if (!getEntityWorld().isClient()) {
            Map<Identifier, Integer> spells = SpellTag.getSpells(getItem());
            if (!spells.containsKey(Spells.INWARD_SPELL)) {
                boolean success = didSpellSucceed(spells);
                for (Map.Entry<Identifier, Integer> entry : spells.entrySet()) {
                    Spell spell = SpellRegistry.getSpell(entry);
                    if (spell != null) {
                        if (success) {
                            if (hitResult.getType() == HitResult.Type.BLOCK) {
                                BlockHitResult blockHitResult = (BlockHitResult) hitResult;
                                spell.execute(getEntityWorld(), this, getOwner(), blockHitResult);
                            } else if (hitResult.getType() == HitResult.Type.ENTITY) {
                                Entity entity = ((EntityHitResult) hitResult).getEntity();
                                spell.execute(world, this, getOwner(), entity);
                            }
                        } else if (getOwner() != null) {
                            if (getOwner() instanceof PlayerEntity) {
                                PlayerEntity player = (PlayerEntity) getOwner();
                                player.playSound(SoundEvents.ENCHANT_THORNS_HIT, SoundCategory.PLAYERS, 1.0f, 1.0f);
                            }
                            spell.execute(world, this, getOwner(), getOwner());
                        }
                    }
                }
                remove();
            }
        }
    }

    @Override
    public void tick() {
        super.tick();
        if (!getEntityWorld().isClient()) {
            Map<Identifier, Integer> spells = SpellTag.getSpells(getItem());
            if (spells.containsKey(Spells.INWARD_SPELL)) {
                if (getOwner() != null) {
                    boolean success = didSpellSucceed(spells);
                    for (Map.Entry<Identifier, Integer> entry : spells.entrySet()) {
                        Spell spell = SpellRegistry.getSpell(entry);
                        if (spell != null) {
                            if (success) {
                                spell.execute(world, this, getOwner(), getOwner());
                            } else if (getOwner() instanceof PlayerEntity) {
                                PlayerEntity player = (PlayerEntity) getOwner();
                                player.playSound(SoundEvents.ENCHANT_THORNS_HIT, SoundCategory.PLAYERS, 1.0f, 1.0f);
                            }
                        }
                    }
                }
                remove();
                return;
            }

            List<ServerPlayerEntity> viewers = Objects.requireNonNull(getServer()).getPlayerManager().getPlayerList();
            for (ServerPlayerEntity viewer : viewers) {
                ((ServerWorld) getEntityWorld()).spawnParticles(viewer, ParticleTypes.WITCH, true, getX(), getY(), getZ(), 8, 0.01d, 0.01d, 0.01d, 0.5d);
            }
        }
    }

    @Override
    protected Item getDefaultItem() {
        return SorceryCraft.SPELL_ITEM;
    }

    @Override
    public Packet<?> createSpawnPacket() {
        return new EntitySpawnS2CPacket(this);
    }
}
